three

package
v0.0.0-...-a6853de Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 3, 2018 License: MIT Imports: 1 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type SetOfStacks

type SetOfStacks interface {
	Push(v interface{})
	Pop() interface{}
	PopAt(id int) interface{}
	Size() int
}

SetOfStacks represents a collection of stacks that combine into a larger stack.

func New

func New(capacity int) SetOfStacks

New returns a SetOfStacks where each stack is of a maximum specified capacity.

Jump to